import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import { loadActiveSession } from "../actionCreators";
import { loadSessionForwards } from "../../session/actionCreators";
import { getActiveForwards } from "../selectors";
import ActiveSessionComponent from "./ActiveSessionComponent";
import ForwardOptionsDialog from "../../session/components/ForwardOptionsDialog";

const ActiveSessionContainer = ({ actions, session, forwards }) => {
  const [expanded, setExpanded] = useState(false);
  const [optionsDialogOpen, setOptionsDialogOpen] = useState(false);
  const [forwardOptions, setForwardOptions] = useState(null);

  useEffect(() => {
    actions.loadActiveSession();
  }, []);

  const handleExpandClick = () => {
    const expand = !expanded;
    setExpanded(expand);
    if (expand) actions.loadSessionForwards(session.sessionId);
  };

  const handleOptionsDialogOpen = (options) => () => {
    setForwardOptions(options);
    setOptionsDialogOpen(true);
  };

  const handleOptionsDialogClose = () => {
    setOptionsDialogOpen(false);
    setForwardOptions(null);
  };

  return (
    <>
      <ActiveSessionComponent
        session={session}
        expanded={expanded}
        handleExpandClick={handleExpandClick}
        forwards={forwards}
        openOptionsDialog={handleOptionsDialogOpen}
      />
      <ForwardOptionsDialog
        open={optionsDialogOpen}
        handleClose={handleOptionsDialogClose}
        options={forwardOptions}
      />
    </>
  );
};

ActiveSessionContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  session: PropTypes.object.isRequired,
  forwards: PropTypes.array
};

function mapStateToProps(state) {
  return {
    session: state.server.activeSession,
    forwards: getActiveForwards(state)
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(
      { loadActiveSession, loadSessionForwards },
      dispatch
    )
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(ActiveSessionContainer);
