import React, { useEffect } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import { loadServerData, loadSystemVersion } from "../actionCreators";
import ServerComponent from "./ServerComponent";
import { withRouter } from "react-router-dom";

const ServerContainer = ({ actions, data, history }) => {
  useEffect(() => {
    actions.loadServerData();
    actions.loadSystemVersion();
  }, []);

  const openAbout = (event) => {
    history.push("/about");
    event.preventDefault();
  };

  return <ServerComponent data={data} openAbout={openAbout} />;
};

ServerContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  data: PropTypes.object.isRequired
};

function mapStateToProps(state) {
  return {
    data: state.server.data
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators({ loadServerData, loadSystemVersion }, dispatch)
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(withRouter(ServerContainer));
